@@ -17,7 +17,7 @@ from prompt_toolkit.filters import Condition, Always
 from prompt_toolkit.history import FileHistory, History
 from prompt_toolkit.interface import CommandLineInterface, Application, AcceptAction
 from prompt_toolkit.key_binding.manager import KeyBindingManager
-from prompt_toolkit.utils import Callback
+from prompt_toolkit.utils import Callback, is_windows
 from prompt_toolkit.validation import SwitchableValidator
 
 from ptpython.completer import PythonCompleter
@@ -31,7 +31,6 @@ from pygments.lexers import PythonLexer
 from functools import partial
 
 import six
-import sys
 import __future__
 
 
@@ -149,9 +148,8 @@ class PythonInput(object):
         # Settings.
         self.show_signature = True
         self.show_docstring = False
-        self.show_completions_toolbar = False
-        self.show_completions_menu = True
         self.completion_visualisation = CompletionVisualisation.POP_UP
+        self.completion_menu_scroll_offset = 1
 
         self.show_line_numbers = True
         self.show_status_bar = True
@@ -180,7 +178,7 @@ class PythonInput(object):
         self._current_code_style_name = 'default'
         self._current_ui_style_name = 'default'
 
-        if sys.platform == 'win32':
+        if is_windows():
             self._current_code_style_name = 'win32'
 
         self._current_style = self._generate_style()
@@ -419,15 +417,15 @@ class PythonInput(object):
                 Option(title='Code',
                        description='Color scheme to use for the Python code.',
                        get_current_value=lambda: self._current_code_style_name,
-                       get_values=lambda: {
-                           name: partial(self.use_code_colorscheme, name) for name in self.code_styles
-                       }),
+                       get_values=lambda: dict(
+                            (name, partial(self.use_code_colorscheme, name)) for name in self.code_styles)
+                       ),
                 Option(title='User interface',
                        description='Color scheme to use for the user interface.',
                        get_current_value=lambda: self._current_ui_style_name,
-                       get_values=lambda: {
-                           name: partial(self.use_ui_colorscheme, name) for name in self.ui_styles
-                       }),
+                       get_values=lambda: dict(
+                            (name, partial(self.use_ui_colorscheme, name)) for name in self.ui_styles)
+                       ),
             ]),
         ]
 
